//
//  CityGuideAppDelegate.m
//  CityGuide
//
//  Created by Alasdair Allan on 07/08/2009.
//  Copyright __MyCompanyName__ 2009. All rights reserved.
//

#import "CityGuideDelegate.h"
#import "RootController.h"
#import "City.h";
#import <sqlite3.h>

@implementation CityGuideDelegate

@synthesize window;
@synthesize viewController;
@synthesize cities;
@synthesize navController;

- (void)applicationDidFinishLaunching:(UIApplication *)application {    
    
	cities = [[NSMutableArray alloc] init];
	NSString *filePath = [self copyDatabaseToDocuments];
	[self readCitiesFromDatabaseWithPath:filePath];
	
	
    // Override point for customization after app launch    
	navController.viewControllers = [NSArray arrayWithObject:viewController];
    [window addSubview:navController.view];
    [window makeKeyAndVisible];
}


- (void)dealloc {
    [viewController release];
    [window release];
	[cities release];
    [super dealloc];
}

#pragma mark Database Methods

- (NSString *)copyDatabaseToDocuments {
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *documentsPath = [paths objectAtIndex:0];
    NSString *filePath = [documentsPath stringByAppendingPathComponent:@"cities.sqlite"];
	
    if ( ![fileManager fileExistsAtPath:filePath] ) {
        NSString *bundleCopy = [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:@"cities.sqlite"];
		[fileManager copyItemAtPath:bundleCopy toPath:filePath error:nil];
    }
    return filePath;
}

-(void) readCitiesFromDatabaseWithPath:(NSString *)filePath {
	sqlite3 *database;
	
	if(sqlite3_open([filePath UTF8String], &database) == SQLITE_OK) {
		const char *sqlStatement = "select * from cities";
		sqlite3_stmt *compiledStatement;
		if(sqlite3_prepare_v2(database, sqlStatement, -1, &compiledStatement, NULL) == SQLITE_OK) {
			while(sqlite3_step(compiledStatement) == SQLITE_ROW) {
				
				NSString *cityName = [NSString stringWithUTF8String:(char *)sqlite3_column_text(compiledStatement, 1)];
				NSString *cityDescription = [NSString stringWithUTF8String:(char *)sqlite3_column_text(compiledStatement, 2)];
				
				NSData *cityData = [[NSData alloc] initWithBytes:sqlite3_column_blob(compiledStatement, 3) length: sqlite3_column_bytes(compiledStatement, 3)];           
				UIImage *cityImage = [UIImage imageWithData:cityData];
				
				City *newCity = [[City alloc] init];
				newCity.cityName = cityName;
				newCity.cityDescription = cityDescription;
				newCity.cityPicture = (UIImage *)cityImage;
				[self.cities addObject:newCity];
				[newCity release];
			}
		}
		sqlite3_finalize(compiledStatement);
	}
	sqlite3_close(database);
}


@end
