//
//  CityGuideViewController.m
//  CityGuide
//
//  Created by Alasdair Allan on 07/08/2009.
//  Copyright __MyCompanyName__ 2009. All rights reserved.
//

#import "RootController.h"
#import "CityGuideDelegate.h"
#import "CityController.h"
#import "AddCityController.h"
#import "City.h"

@implementation RootController

@synthesize tableView;

#pragma mark Instance Methods

-(void)setEditing:(BOOL)editing animated:(BOOL) animated {
	if( editing != self.editing ) {
		[super setEditing:editing animated:animated];
		[tableView setEditing:editing animated:animated];
			
		NSMutableArray *indicies = [[NSMutableArray alloc] init];
		[indicies autorelease];
		for(int i=0; i < cities.count; i++ ) {
			[indicies addObject:[NSIndexPath indexPathForRow:i inSection:0]];
		}
		NSArray *lastIndex = [NSArray arrayWithObject:[NSIndexPath indexPathForRow:cities.count inSection:0]];		
		
		if (editing == YES ) {
			for(int i=0; i < cities.count; i++ ) {
				UITableViewCell *cell = [tableView cellForRowAtIndexPath:[indicies objectAtIndex:i]];
				[cell setSelectionStyle:UITableViewCellSelectionStyleNone];
			}
			[tableView insertRowsAtIndexPaths:lastIndex withRowAnimation:UITableViewRowAnimationLeft];
		} else {
			for(int i=0; i < cities.count; i++ ) {
				UITableViewCell *cell = [tableView cellForRowAtIndexPath:[indicies objectAtIndex:i]];
				[cell setSelectionStyle:UITableViewCellSelectionStyleBlue];
			}
			[tableView deleteRowsAtIndexPaths:lastIndex withRowAnimation:UITableViewRowAnimationLeft];
		}
 	}
}

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidLoad {
	self.title = @"City Guide";
	self.navigationItem.rightBarButtonItem = self.editButtonItem;
	
	CityGuideDelegate *delegate = (CityGuideDelegate *)[[UIApplication sharedApplication] delegate];
	cities = delegate.cities;
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}

- (void)dealloc {
	[tableView release];
	[cities release];
    [super dealloc];
}

#pragma mark UITableViewDataSource Methods

- (UITableViewCell *)tableView:(UITableView *)tv cellForRowAtIndexPath:(NSIndexPath *)indexPath {
	UITableViewCell *cell = [tv dequeueReusableCellWithIdentifier:@"cell"];
	if( nil == cell ) {
		cell = [[[UITableViewCell alloc] initWithFrame:CGRectZero reuseIdentifier:@"cell"] autorelease];
	}
	
	if (indexPath.row < cities.count ) {
		City *thisCity = [cities objectAtIndex:indexPath.row];
		cell.textLabel.text = thisCity.cityName;
		cell.textLabel.textColor = [UIColor blackColor];
		cell.editingAccessoryType = UITableViewCellAccessoryNone;
		if (self.editing) {
			[cell setSelectionStyle:UITableViewCellSelectionStyleNone];
		}

 	} else {
		cell.textLabel.text = @"Add New City...";
		cell.textLabel.textColor = [UIColor lightGrayColor];
		cell.editingAccessoryType = UITableViewCellAccessoryDisclosureIndicator;
	}
	return cell;
}

- (NSInteger)tableView:(UITableView *)tv numberOfRowsInSection:(NSInteger)section {
	NSInteger count = cities.count;
	if(self.editing) {
		count = count + 1;
	}
	return count;
}

- (void) tableView:(UITableView *)tv commitEditingStyle:(UITableViewCellEditingStyle) editing forRowAtIndexPath:(NSIndexPath *)indexPath {
	if( editing == UITableViewCellEditingStyleDelete ) {
		[cities removeObjectAtIndex:indexPath.row];
		[tv deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationLeft];
	}
}

#pragma mark UITableViewDelegate Methods

- (void)tableView:(UITableView *)tv didSelectRowAtIndexPath:(NSIndexPath *)indexPath {	
	CityGuideDelegate *delegate = (CityGuideDelegate *)[[UIApplication sharedApplication] delegate];

	if (indexPath.row < cities.count && !self.editing ) {

		CityController *city = [[CityController alloc] initWithIndexPath:indexPath];
		[delegate.navController pushViewController:city animated:YES];
		[city release];
	}
	
	if( indexPath.row == cities.count && self.editing ) {
		
		AddCityController *addCity = [[AddCityController alloc] init];
		[delegate.navController pushViewController:addCity animated:YES];
		[addCity release];
	}
	
	[tv deselectRowAtIndexPath:indexPath animated:YES];
}

- (UITableViewCellEditingStyle)tableView:(UITableView *)tv editingStyleForRowAtIndexPath:(NSIndexPath *)indexPath {
	
	
	if (indexPath.row < cities.count ) {
		return UITableViewCellEditingStyleDelete;
	} else {
		return UITableViewCellEditingStyleInsert;
	}

}


@end
